Crate stefans_utils

Crate stefans_utils 

A collection of useful Rust utility functions, types, and traits.

Modules

as_arc
as_bool
Contains the AsBool trait used for converting a reference of self into a bool.
as_clone
as_copy
as_str
bool
Contains trait implementations for the bool type
collect_by_key
comparator
dependencies
expect_comparison
expect_length
find_upwards
from_str
hash_map
hash_set
literals
map
Contains the Map trait which collects the ok, ok_or, map, unwrap and expect functions as seen on TV
map_into
option
Contains traits and utility functions for core::option::Option<T>
path
Contains trait implementations and utility functions for std::path::Path
php_safe_hashmap
php_safe_indexmap
prelude
Re-exports of mostly all utils
secret
Contains the Secret<T> struct, designed to wrap values that should never appear formatted with Display or Debug in logs or other output.
single_kv_map
str
string
try_map_into
unwrap_into
vec
with_len

Macros

literal
literal_bool
literal_f32
literal_f64
literal_i8
literal_i16
literal_i32
literal_i64
literal_i128
literal_isize
literal_str
literal_u8
literal_u16
literal_u32
literal_u64
literal_u128
literal_usize